# mynt

_Another static site generator?_

With the ever growing population of static site generators, all filling a certain need, I've yet to find one that allows the generation of anything but the simplest of blogs.

That's where mynt comes in, being designed to give you all the features of a CMS with none of the often rigid implementations of those features.


### Install

From PyPI:

    $ pip install mynt

Latest trunk:

    $ pip install git+https://github.com/Anomareh/mynt.git


### Getting started

After installing mynt head on over and give the [quickstart][quickstart] page and [docs][docs] a read.


### Dependencies

+ [Hoep][hoep]
+ [Jinja2][jinja]
+ [Pygments][pygments]
+ [PyYAML][pyyaml]
+ [watchdog][watchdog]

#### Optional

+ [Docutils][docutils] _(reST)_


### Support

If you run into any issues or have any questions, either open an [issue][issues] or hop in #mynt on irc.freenode.net.


[docs]: http://mynt.uhnomoli.com/
[docutils]: http://docutils.sourceforge.net/
[hoep]: https://github.com/Anomareh/Hoep
[issues]: https://github.com/Anomareh/mynt/issues
[jinja]: http://jinja.pocoo.org/
[pygments]: http://pygments.org/
[pyyaml]: http://pyyaml.org/
[quickstart]: http://mynt.uhnomoli.com/docs/quickstart/
[watchdog]: http://packages.python.org/watchdog/
